bayespy.inference.vmp.nodes.gaussian.WrapToGaussianWishart.delete
=================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: WrapToGaussianWishart.delete